You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@airavata.apache.org by sc...@apache.org on 2015/06/07 19:00:47 UTC

[06/44] airavata git commit: Changing the thrift model variable names to lower camel case

http://git-wip-us.apache.org/repos/asf/airavata/blob/b376aa85/airavata-api/airavata-client-sdks/airavata-python-sdk/src/main/resources/lib/apache/airavata/model/workspace/experiment/ttypes.py
----------------------------------------------------------------------
diff --git a/airavata-api/airavata-client-sdks/airavata-python-sdk/src/main/resources/lib/apache/airavata/model/workspace/experiment/ttypes.py b/airavata-api/airavata-client-sdks/airavata-python-sdk/src/main/resources/lib/apache/airavata/model/workspace/experiment/ttypes.py
index 3ffe2b2..18bb67b 100644
--- a/airavata-api/airavata-client-sdks/airavata-python-sdk/src/main/resources/lib/apache/airavata/model/workspace/experiment/ttypes.py
+++ b/airavata-api/airavata-client-sdks/airavata-python-sdk/src/main/resources/lib/apache/airavata/model/workspace/experiment/ttypes.py
@@ -774,7 +774,7 @@ class ComputationalResourceScheduling:
 
   Attributes:
    - resourceHostId
-   - totalCPUCount
+   - totalCpuCount
    - nodeCount
    - numberOfThreads
    - queueName
@@ -788,7 +788,7 @@ class ComputationalResourceScheduling:
   thrift_spec = (
     None, # 0
     (1, TType.STRING, 'resourceHostId', None, None, ), # 1
-    (2, TType.I32, 'totalCPUCount', None, None, ), # 2
+    (2, TType.I32, 'totalCpuCount', None, None, ), # 2
     (3, TType.I32, 'nodeCount', None, None, ), # 3
     (4, TType.I32, 'numberOfThreads', None, None, ), # 4
     (5, TType.STRING, 'queueName', None, None, ), # 5
@@ -799,9 +799,9 @@ class ComputationalResourceScheduling:
     (10, TType.STRING, 'chassisName', None, None, ), # 10
   )
 
-  def __init__(self, resourceHostId=None, totalCPUCount=None, nodeCount=None, numberOfThreads=None, queueName=None, wallTimeLimit=None, jobStartTime=None, totalPhysicalMemory=None, computationalProjectAccount=None, chassisName=None,):
+  def __init__(self, resourceHostId=None, totalCpuCount=None, nodeCount=None, numberOfThreads=None, queueName=None, wallTimeLimit=None, jobStartTime=None, totalPhysicalMemory=None, computationalProjectAccount=None, chassisName=None,):
     self.resourceHostId = resourceHostId
-    self.totalCPUCount = totalCPUCount
+    self.totalCpuCount = totalCpuCount
     self.nodeCount = nodeCount
     self.numberOfThreads = numberOfThreads
     self.queueName = queueName
@@ -827,7 +827,7 @@ class ComputationalResourceScheduling:
           iprot.skip(ftype)
       elif fid == 2:
         if ftype == TType.I32:
-          self.totalCPUCount = iprot.readI32();
+          self.totalCpuCount = iprot.readI32();
         else:
           iprot.skip(ftype)
       elif fid == 3:
@@ -884,9 +884,9 @@ class ComputationalResourceScheduling:
       oprot.writeFieldBegin('resourceHostId', TType.STRING, 1)
       oprot.writeString(self.resourceHostId)
       oprot.writeFieldEnd()
-    if self.totalCPUCount is not None:
-      oprot.writeFieldBegin('totalCPUCount', TType.I32, 2)
-      oprot.writeI32(self.totalCPUCount)
+    if self.totalCpuCount is not None:
+      oprot.writeFieldBegin('totalCpuCount', TType.I32, 2)
+      oprot.writeI32(self.totalCpuCount)
       oprot.writeFieldEnd()
     if self.nodeCount is not None:
       oprot.writeFieldBegin('nodeCount', TType.I32, 3)
@@ -1227,7 +1227,7 @@ class UserConfigurationData:
    - advanceOutputDataHandling
    - qosParams
    - throttleResources
-   - userDN
+   - userDn
    - generateCert
   """
 
@@ -1241,11 +1241,11 @@ class UserConfigurationData:
     (6, TType.STRUCT, 'advanceOutputDataHandling', (AdvancedOutputDataHandling, AdvancedOutputDataHandling.thrift_spec), None, ), # 6
     (7, TType.STRUCT, 'qosParams', (QualityOfServiceParams, QualityOfServiceParams.thrift_spec), None, ), # 7
     (8, TType.BOOL, 'throttleResources', None, False, ), # 8
-    (9, TType.STRING, 'userDN', None, None, ), # 9
+    (9, TType.STRING, 'userDn', None, None, ), # 9
     (10, TType.BOOL, 'generateCert', None, False, ), # 10
   )
 
-  def __init__(self, airavataAutoSchedule=thrift_spec[1][4], overrideManualScheduledParams=thrift_spec[2][4], shareExperimentPublicly=thrift_spec[3][4], computationalResourceScheduling=None, advanceInputDataHandling=None, advanceOutputDataHandling=None, qosParams=None, throttleResources=thrift_spec[8][4], userDN=None, generateCert=thrift_spec[10][4],):
+  def __init__(self, airavataAutoSchedule=thrift_spec[1][4], overrideManualScheduledParams=thrift_spec[2][4], shareExperimentPublicly=thrift_spec[3][4], computationalResourceScheduling=None, advanceInputDataHandling=None, advanceOutputDataHandling=None, qosParams=None, throttleResources=thrift_spec[8][4], userDn=None, generateCert=thrift_spec[10][4],):
     self.airavataAutoSchedule = airavataAutoSchedule
     self.overrideManualScheduledParams = overrideManualScheduledParams
     self.shareExperimentPublicly = shareExperimentPublicly
@@ -1254,7 +1254,7 @@ class UserConfigurationData:
     self.advanceOutputDataHandling = advanceOutputDataHandling
     self.qosParams = qosParams
     self.throttleResources = throttleResources
-    self.userDN = userDN
+    self.userDn = userDn
     self.generateCert = generateCert
 
   def read(self, iprot):
@@ -1312,7 +1312,7 @@ class UserConfigurationData:
           iprot.skip(ftype)
       elif fid == 9:
         if ftype == TType.STRING:
-          self.userDN = iprot.readString();
+          self.userDn = iprot.readString();
         else:
           iprot.skip(ftype)
       elif fid == 10:
@@ -1362,9 +1362,9 @@ class UserConfigurationData:
       oprot.writeFieldBegin('throttleResources', TType.BOOL, 8)
       oprot.writeBool(self.throttleResources)
       oprot.writeFieldEnd()
-    if self.userDN is not None:
-      oprot.writeFieldBegin('userDN', TType.STRING, 9)
-      oprot.writeString(self.userDN)
+    if self.userDn is not None:
+      oprot.writeFieldBegin('userDn', TType.STRING, 9)
+      oprot.writeString(self.userDn)
       oprot.writeFieldEnd()
     if self.generateCert is not None:
       oprot.writeFieldBegin('generateCert', TType.BOOL, 10)
@@ -1395,7 +1395,7 @@ class UserConfigurationData:
 class ErrorDetails:
   """
   Attributes:
-   - errorID
+   - errorId
    - creationTime
    - actualErrorMessage
    - userFriendlyMessage
@@ -1408,7 +1408,7 @@ class ErrorDetails:
 
   thrift_spec = (
     None, # 0
-    (1, TType.STRING, 'errorID', None, "DO_NOT_SET_AT_CLIENTS", ), # 1
+    (1, TType.STRING, 'errorId', None, "DO_NOT_SET_AT_CLIENTS", ), # 1
     (2, TType.I64, 'creationTime', None, None, ), # 2
     (3, TType.STRING, 'actualErrorMessage', None, None, ), # 3
     (4, TType.STRING, 'userFriendlyMessage', None, None, ), # 4
@@ -1419,8 +1419,8 @@ class ErrorDetails:
     (9, TType.LIST, 'rootCauseErrorIdList', (TType.STRING,None), None, ), # 9
   )
 
-  def __init__(self, errorID=thrift_spec[1][4], creationTime=None, actualErrorMessage=None, userFriendlyMessage=None, errorCategory=None, transientOrPersistent=thrift_spec[6][4], correctiveAction=None, actionableGroup=None, rootCauseErrorIdList=None,):
-    self.errorID = errorID
+  def __init__(self, errorId=thrift_spec[1][4], creationTime=None, actualErrorMessage=None, userFriendlyMessage=None, errorCategory=None, transientOrPersistent=thrift_spec[6][4], correctiveAction=None, actionableGroup=None, rootCauseErrorIdList=None,):
+    self.errorId = errorId
     self.creationTime = creationTime
     self.actualErrorMessage = actualErrorMessage
     self.userFriendlyMessage = userFriendlyMessage
@@ -1441,7 +1441,7 @@ class ErrorDetails:
         break
       if fid == 1:
         if ftype == TType.STRING:
-          self.errorID = iprot.readString();
+          self.errorId = iprot.readString();
         else:
           iprot.skip(ftype)
       elif fid == 2:
@@ -1499,9 +1499,9 @@ class ErrorDetails:
       oprot.trans.write(fastbinary.encode_binary(self, (self.__class__, self.thrift_spec)))
       return
     oprot.writeStructBegin('ErrorDetails')
-    if self.errorID is not None:
-      oprot.writeFieldBegin('errorID', TType.STRING, 1)
-      oprot.writeString(self.errorID)
+    if self.errorId is not None:
+      oprot.writeFieldBegin('errorId', TType.STRING, 1)
+      oprot.writeString(self.errorId)
       oprot.writeFieldEnd()
     if self.creationTime is not None:
       oprot.writeFieldBegin('creationTime', TType.I64, 2)
@@ -1542,8 +1542,8 @@ class ErrorDetails:
     oprot.writeStructEnd()
 
   def validate(self):
-    if self.errorID is None:
-      raise TProtocol.TProtocolException(message='Required field errorID is unset!')
+    if self.errorId is None:
+      raise TProtocol.TProtocolException(message='Required field errorId is unset!')
     return
 
 
@@ -1561,7 +1561,7 @@ class ErrorDetails:
 class JobDetails:
   """
   Attributes:
-   - jobID
+   - jobId
    - jobDescription
    - creationTime
    - jobStatus
@@ -1574,7 +1574,7 @@ class JobDetails:
 
   thrift_spec = (
     None, # 0
-    (1, TType.STRING, 'jobID', None, "DO_NOT_SET_AT_CLIENTS", ), # 1
+    (1, TType.STRING, 'jobId', None, "DO_NOT_SET_AT_CLIENTS", ), # 1
     (2, TType.STRING, 'jobDescription', None, None, ), # 2
     (3, TType.I64, 'creationTime', None, None, ), # 3
     (4, TType.STRUCT, 'jobStatus', (JobStatus, JobStatus.thrift_spec), None, ), # 4
@@ -1585,8 +1585,8 @@ class JobDetails:
     (9, TType.STRING, 'workingDir', None, None, ), # 9
   )
 
-  def __init__(self, jobID=thrift_spec[1][4], jobDescription=None, creationTime=None, jobStatus=None, applicationStatus=None, errors=None, computeResourceConsumed=None, jobName=None, workingDir=None,):
-    self.jobID = jobID
+  def __init__(self, jobId=thrift_spec[1][4], jobDescription=None, creationTime=None, jobStatus=None, applicationStatus=None, errors=None, computeResourceConsumed=None, jobName=None, workingDir=None,):
+    self.jobId = jobId
     self.jobDescription = jobDescription
     self.creationTime = creationTime
     self.jobStatus = jobStatus
@@ -1607,7 +1607,7 @@ class JobDetails:
         break
       if fid == 1:
         if ftype == TType.STRING:
-          self.jobID = iprot.readString();
+          self.jobId = iprot.readString();
         else:
           iprot.skip(ftype)
       elif fid == 2:
@@ -1668,9 +1668,9 @@ class JobDetails:
       oprot.trans.write(fastbinary.encode_binary(self, (self.__class__, self.thrift_spec)))
       return
     oprot.writeStructBegin('JobDetails')
-    if self.jobID is not None:
-      oprot.writeFieldBegin('jobID', TType.STRING, 1)
-      oprot.writeString(self.jobID)
+    if self.jobId is not None:
+      oprot.writeFieldBegin('jobId', TType.STRING, 1)
+      oprot.writeString(self.jobId)
       oprot.writeFieldEnd()
     if self.jobDescription is not None:
       oprot.writeFieldBegin('jobDescription', TType.STRING, 2)
@@ -1711,8 +1711,8 @@ class JobDetails:
     oprot.writeStructEnd()
 
   def validate(self):
-    if self.jobID is None:
-      raise TProtocol.TProtocolException(message='Required field jobID is unset!')
+    if self.jobId is None:
+      raise TProtocol.TProtocolException(message='Required field jobId is unset!')
     if self.jobDescription is None:
       raise TProtocol.TProtocolException(message='Required field jobDescription is unset!')
     return
@@ -1732,7 +1732,7 @@ class JobDetails:
 class DataTransferDetails:
   """
   Attributes:
-   - transferID
+   - transferId
    - creationTime
    - transferDescription
    - transferStatus
@@ -1740,14 +1740,14 @@ class DataTransferDetails:
 
   thrift_spec = (
     None, # 0
-    (1, TType.STRING, 'transferID', None, "DO_NOT_SET_AT_CLIENTS", ), # 1
+    (1, TType.STRING, 'transferId', None, "DO_NOT_SET_AT_CLIENTS", ), # 1
     (2, TType.I64, 'creationTime', None, None, ), # 2
     (3, TType.STRING, 'transferDescription', None, None, ), # 3
     (4, TType.STRUCT, 'transferStatus', (TransferStatus, TransferStatus.thrift_spec), None, ), # 4
   )
 
-  def __init__(self, transferID=thrift_spec[1][4], creationTime=None, transferDescription=None, transferStatus=None,):
-    self.transferID = transferID
+  def __init__(self, transferId=thrift_spec[1][4], creationTime=None, transferDescription=None, transferStatus=None,):
+    self.transferId = transferId
     self.creationTime = creationTime
     self.transferDescription = transferDescription
     self.transferStatus = transferStatus
@@ -1763,7 +1763,7 @@ class DataTransferDetails:
         break
       if fid == 1:
         if ftype == TType.STRING:
-          self.transferID = iprot.readString();
+          self.transferId = iprot.readString();
         else:
           iprot.skip(ftype)
       elif fid == 2:
@@ -1792,9 +1792,9 @@ class DataTransferDetails:
       oprot.trans.write(fastbinary.encode_binary(self, (self.__class__, self.thrift_spec)))
       return
     oprot.writeStructBegin('DataTransferDetails')
-    if self.transferID is not None:
-      oprot.writeFieldBegin('transferID', TType.STRING, 1)
-      oprot.writeString(self.transferID)
+    if self.transferId is not None:
+      oprot.writeFieldBegin('transferId', TType.STRING, 1)
+      oprot.writeString(self.transferId)
       oprot.writeFieldEnd()
     if self.creationTime is not None:
       oprot.writeFieldBegin('creationTime', TType.I64, 2)
@@ -1812,8 +1812,8 @@ class DataTransferDetails:
     oprot.writeStructEnd()
 
   def validate(self):
-    if self.transferID is None:
-      raise TProtocol.TProtocolException(message='Required field transferID is unset!')
+    if self.transferId is None:
+      raise TProtocol.TProtocolException(message='Required field transferId is unset!')
     if self.transferDescription is None:
       raise TProtocol.TProtocolException(message='Required field transferDescription is unset!')
     return
@@ -1838,7 +1838,7 @@ class TaskDetails:
 
 
   Attributes:
-   - taskID
+   - taskId
    - creationTime
    - applicationId
    - applicationVersion
@@ -1858,7 +1858,7 @@ class TaskDetails:
 
   thrift_spec = (
     None, # 0
-    (1, TType.STRING, 'taskID', None, "DO_NOT_SET_AT_CLIENTS", ), # 1
+    (1, TType.STRING, 'taskId', None, "DO_NOT_SET_AT_CLIENTS", ), # 1
     (2, TType.I64, 'creationTime', None, None, ), # 2
     (3, TType.STRING, 'applicationId', None, None, ), # 3
     (4, TType.STRING, 'applicationVersion', None, None, ), # 4
@@ -1876,8 +1876,8 @@ class TaskDetails:
     (16, TType.LIST, 'emailAddresses', (TType.STRING,None), None, ), # 16
   )
 
-  def __init__(self, taskID=thrift_spec[1][4], creationTime=None, applicationId=None, applicationVersion=None, applicationDeploymentId=None, applicationInputs=None, applicationOutputs=None, taskScheduling=None, advancedInputDataHandling=None, advancedOutputDataHandling=None, taskStatus=None, jobDetailsList=None, dataTransferDetailsList=None, errors=None, enableEmailNotification=None, emailAddresses=None,):
-    self.taskID = taskID
+  def __init__(self, taskId=thrift_spec[1][4], creationTime=None, applicationId=None, applicationVersion=None, applicationDeploymentId=None, applicationInputs=None, applicationOutputs=None, taskScheduling=None, advancedInputDataHandling=None, advancedOutputDataHandling=None, taskStatus=None, jobDetailsList=None, dataTransferDetailsList=None, errors=None, enableEmailNotification=None, emailAddresses=None,):
+    self.taskId = taskId
     self.creationTime = creationTime
     self.applicationId = applicationId
     self.applicationVersion = applicationVersion
@@ -1905,7 +1905,7 @@ class TaskDetails:
         break
       if fid == 1:
         if ftype == TType.STRING:
-          self.taskID = iprot.readString();
+          self.taskId = iprot.readString();
         else:
           iprot.skip(ftype)
       elif fid == 2:
@@ -2032,9 +2032,9 @@ class TaskDetails:
       oprot.trans.write(fastbinary.encode_binary(self, (self.__class__, self.thrift_spec)))
       return
     oprot.writeStructBegin('TaskDetails')
-    if self.taskID is not None:
-      oprot.writeFieldBegin('taskID', TType.STRING, 1)
-      oprot.writeString(self.taskID)
+    if self.taskId is not None:
+      oprot.writeFieldBegin('taskId', TType.STRING, 1)
+      oprot.writeString(self.taskId)
       oprot.writeFieldEnd()
     if self.creationTime is not None:
       oprot.writeFieldBegin('creationTime', TType.I64, 2)
@@ -2118,8 +2118,8 @@ class TaskDetails:
     oprot.writeStructEnd()
 
   def validate(self):
-    if self.taskID is None:
-      raise TProtocol.TProtocolException(message='Required field taskID is unset!')
+    if self.taskId is None:
+      raise TProtocol.TProtocolException(message='Required field taskId is unset!')
     return
 
 
@@ -2531,8 +2531,8 @@ class Experiment:
      The verbose description of the experiment. This is an optional parameter.
 
   Attributes:
-   - experimentID
-   - projectID
+   - experimentId
+   - projectId
    - creationTime
    - userName
    - name
@@ -2556,8 +2556,8 @@ class Experiment:
 
   thrift_spec = (
     None, # 0
-    (1, TType.STRING, 'experimentID', None, "DO_NOT_SET_AT_CLIENTS", ), # 1
-    (2, TType.STRING, 'projectID', None, "DEFAULT", ), # 2
+    (1, TType.STRING, 'experimentId', None, "DO_NOT_SET_AT_CLIENTS", ), # 1
+    (2, TType.STRING, 'projectId', None, "DEFAULT", ), # 2
     (3, TType.I64, 'creationTime', None, None, ), # 3
     (4, TType.STRING, 'userName', None, None, ), # 4
     (5, TType.STRING, 'name', None, None, ), # 5
@@ -2579,9 +2579,9 @@ class Experiment:
     (21, TType.LIST, 'errors', (TType.STRUCT,(ErrorDetails, ErrorDetails.thrift_spec)), None, ), # 21
   )
 
-  def __init__(self, experimentID=thrift_spec[1][4], projectID=thrift_spec[2][4], creationTime=None, userName=None, name=None, description=None, applicationId=None, applicationVersion=None, workflowTemplateId=None, workflowTemplateVersion=None, gatewayExecutionId=None, enableEmailNotification=None, emailAddresses=None, userConfigurationData=None, workflowExecutionInstanceId=None, experimentInputs=None, experimentOutputs=None, experimentStatus=None, stateChangeList=None, workflowNodeDetailsList=None, errors=None,):
-    self.experimentID = experimentID
-    self.projectID = projectID
+  def __init__(self, experimentId=thrift_spec[1][4], projectId=thrift_spec[2][4], creationTime=None, userName=None, name=None, description=None, applicationId=None, applicationVersion=None, workflowTemplateId=None, workflowTemplateVersion=None, gatewayExecutionId=None, enableEmailNotification=None, emailAddresses=None, userConfigurationData=None, workflowExecutionInstanceId=None, experimentInputs=None, experimentOutputs=None, experimentStatus=None, stateChangeList=None, workflowNodeDetailsList=None, errors=None,):
+    self.experimentId = experimentId
+    self.projectId = projectId
     self.creationTime = creationTime
     self.userName = userName
     self.name = name
@@ -2613,12 +2613,12 @@ class Experiment:
         break
       if fid == 1:
         if ftype == TType.STRING:
-          self.experimentID = iprot.readString();
+          self.experimentId = iprot.readString();
         else:
           iprot.skip(ftype)
       elif fid == 2:
         if ftype == TType.STRING:
-          self.projectID = iprot.readString();
+          self.projectId = iprot.readString();
         else:
           iprot.skip(ftype)
       elif fid == 3:
@@ -2763,13 +2763,13 @@ class Experiment:
       oprot.trans.write(fastbinary.encode_binary(self, (self.__class__, self.thrift_spec)))
       return
     oprot.writeStructBegin('Experiment')
-    if self.experimentID is not None:
-      oprot.writeFieldBegin('experimentID', TType.STRING, 1)
-      oprot.writeString(self.experimentID)
+    if self.experimentId is not None:
+      oprot.writeFieldBegin('experimentId', TType.STRING, 1)
+      oprot.writeString(self.experimentId)
       oprot.writeFieldEnd()
-    if self.projectID is not None:
-      oprot.writeFieldBegin('projectID', TType.STRING, 2)
-      oprot.writeString(self.projectID)
+    if self.projectId is not None:
+      oprot.writeFieldBegin('projectId', TType.STRING, 2)
+      oprot.writeString(self.projectId)
       oprot.writeFieldEnd()
     if self.creationTime is not None:
       oprot.writeFieldBegin('creationTime', TType.I64, 3)
@@ -2869,10 +2869,10 @@ class Experiment:
     oprot.writeStructEnd()
 
   def validate(self):
-    if self.experimentID is None:
-      raise TProtocol.TProtocolException(message='Required field experimentID is unset!')
-    if self.projectID is None:
-      raise TProtocol.TProtocolException(message='Required field projectID is unset!')
+    if self.experimentId is None:
+      raise TProtocol.TProtocolException(message='Required field experimentId is unset!')
+    if self.projectId is None:
+      raise TProtocol.TProtocolException(message='Required field projectId is unset!')
     if self.userName is None:
       raise TProtocol.TProtocolException(message='Required field userName is unset!')
     if self.name is None:
@@ -2894,8 +2894,8 @@ class Experiment:
 class ExperimentSummary:
   """
   Attributes:
-   - experimentID
-   - projectID
+   - experimentId
+   - projectId
    - creationTime
    - userName
    - name
@@ -2907,8 +2907,8 @@ class ExperimentSummary:
 
   thrift_spec = (
     None, # 0
-    (1, TType.STRING, 'experimentID', None, None, ), # 1
-    (2, TType.STRING, 'projectID', None, None, ), # 2
+    (1, TType.STRING, 'experimentId', None, None, ), # 1
+    (2, TType.STRING, 'projectId', None, None, ), # 2
     (3, TType.I64, 'creationTime', None, None, ), # 3
     (4, TType.STRING, 'userName', None, None, ), # 4
     (5, TType.STRING, 'name', None, None, ), # 5
@@ -2918,9 +2918,9 @@ class ExperimentSummary:
     (9, TType.LIST, 'errors', (TType.STRUCT,(ErrorDetails, ErrorDetails.thrift_spec)), None, ), # 9
   )
 
-  def __init__(self, experimentID=None, projectID=None, creationTime=None, userName=None, name=None, description=None, applicationId=None, experimentStatus=None, errors=None,):
-    self.experimentID = experimentID
-    self.projectID = projectID
+  def __init__(self, experimentId=None, projectId=None, creationTime=None, userName=None, name=None, description=None, applicationId=None, experimentStatus=None, errors=None,):
+    self.experimentId = experimentId
+    self.projectId = projectId
     self.creationTime = creationTime
     self.userName = userName
     self.name = name
@@ -2940,12 +2940,12 @@ class ExperimentSummary:
         break
       if fid == 1:
         if ftype == TType.STRING:
-          self.experimentID = iprot.readString();
+          self.experimentId = iprot.readString();
         else:
           iprot.skip(ftype)
       elif fid == 2:
         if ftype == TType.STRING:
-          self.projectID = iprot.readString();
+          self.projectId = iprot.readString();
         else:
           iprot.skip(ftype)
       elif fid == 3:
@@ -3000,13 +3000,13 @@ class ExperimentSummary:
       oprot.trans.write(fastbinary.encode_binary(self, (self.__class__, self.thrift_spec)))
       return
     oprot.writeStructBegin('ExperimentSummary')
-    if self.experimentID is not None:
-      oprot.writeFieldBegin('experimentID', TType.STRING, 1)
-      oprot.writeString(self.experimentID)
+    if self.experimentId is not None:
+      oprot.writeFieldBegin('experimentId', TType.STRING, 1)
+      oprot.writeString(self.experimentId)
       oprot.writeFieldEnd()
-    if self.projectID is not None:
-      oprot.writeFieldBegin('projectID', TType.STRING, 2)
-      oprot.writeString(self.projectID)
+    if self.projectId is not None:
+      oprot.writeFieldBegin('projectId', TType.STRING, 2)
+      oprot.writeString(self.projectId)
       oprot.writeFieldEnd()
     if self.creationTime is not None:
       oprot.writeFieldBegin('creationTime', TType.I64, 3)
@@ -3043,10 +3043,10 @@ class ExperimentSummary:
     oprot.writeStructEnd()
 
   def validate(self):
-    if self.experimentID is None:
-      raise TProtocol.TProtocolException(message='Required field experimentID is unset!')
-    if self.projectID is None:
-      raise TProtocol.TProtocolException(message='Required field projectID is unset!')
+    if self.experimentId is None:
+      raise TProtocol.TProtocolException(message='Required field experimentId is unset!')
+    if self.projectId is None:
+      raise TProtocol.TProtocolException(message='Required field projectId is unset!')
     if self.userName is None:
       raise TProtocol.TProtocolException(message='Required field userName is unset!')
     if self.name is None:

http://git-wip-us.apache.org/repos/asf/airavata/blob/b376aa85/airavata-api/airavata-client-sdks/airavata-python-sdk/src/main/resources/lib/apache/airavata/model/workspace/ttypes.py
----------------------------------------------------------------------
diff --git a/airavata-api/airavata-client-sdks/airavata-python-sdk/src/main/resources/lib/apache/airavata/model/workspace/ttypes.py b/airavata-api/airavata-client-sdks/airavata-python-sdk/src/main/resources/lib/apache/airavata/model/workspace/ttypes.py
index 25d2fb0..97dbe6c 100644
--- a/airavata-api/airavata-client-sdks/airavata-python-sdk/src/main/resources/lib/apache/airavata/model/workspace/ttypes.py
+++ b/airavata-api/airavata-client-sdks/airavata-python-sdk/src/main/resources/lib/apache/airavata/model/workspace/ttypes.py
@@ -96,7 +96,7 @@ class Group:
 class Project:
   """
   Attributes:
-   - projectID
+   - projectId
    - owner
    - name
    - description
@@ -107,7 +107,7 @@ class Project:
 
   thrift_spec = (
     None, # 0
-    (1, TType.STRING, 'projectID', None, "DEFAULT", ), # 1
+    (1, TType.STRING, 'projectId', None, "DEFAULT", ), # 1
     (2, TType.STRING, 'owner', None, None, ), # 2
     (3, TType.STRING, 'name', None, None, ), # 3
     (4, TType.STRING, 'description', None, None, ), # 4
@@ -116,8 +116,8 @@ class Project:
     (7, TType.LIST, 'sharedGroups', (TType.STRING,None), None, ), # 7
   )
 
-  def __init__(self, projectID=thrift_spec[1][4], owner=None, name=None, description=None, creationTime=None, sharedUsers=None, sharedGroups=None,):
-    self.projectID = projectID
+  def __init__(self, projectId=thrift_spec[1][4], owner=None, name=None, description=None, creationTime=None, sharedUsers=None, sharedGroups=None,):
+    self.projectId = projectId
     self.owner = owner
     self.name = name
     self.description = description
@@ -136,7 +136,7 @@ class Project:
         break
       if fid == 1:
         if ftype == TType.STRING:
-          self.projectID = iprot.readString();
+          self.projectId = iprot.readString();
         else:
           iprot.skip(ftype)
       elif fid == 2:
@@ -189,9 +189,9 @@ class Project:
       oprot.trans.write(fastbinary.encode_binary(self, (self.__class__, self.thrift_spec)))
       return
     oprot.writeStructBegin('Project')
-    if self.projectID is not None:
-      oprot.writeFieldBegin('projectID', TType.STRING, 1)
-      oprot.writeString(self.projectID)
+    if self.projectId is not None:
+      oprot.writeFieldBegin('projectId', TType.STRING, 1)
+      oprot.writeString(self.projectId)
       oprot.writeFieldEnd()
     if self.owner is not None:
       oprot.writeFieldBegin('owner', TType.STRING, 2)
@@ -227,8 +227,8 @@ class Project:
     oprot.writeStructEnd()
 
   def validate(self):
-    if self.projectID is None:
-      raise TProtocol.TProtocolException(message='Required field projectID is unset!')
+    if self.projectId is None:
+      raise TProtocol.TProtocolException(message='Required field projectId is unset!')
     if self.owner is None:
       raise TProtocol.TProtocolException(message='Required field owner is unset!')
     if self.name is None:

http://git-wip-us.apache.org/repos/asf/airavata/blob/b376aa85/airavata-api/airavata-client-sdks/java-client-samples/src/main/java/org/apache/airavata/client/samples/CancelExperiments.java
----------------------------------------------------------------------
diff --git a/airavata-api/airavata-client-sdks/java-client-samples/src/main/java/org/apache/airavata/client/samples/CancelExperiments.java b/airavata-api/airavata-client-sdks/java-client-samples/src/main/java/org/apache/airavata/client/samples/CancelExperiments.java
index 8d41295..bd8fc37 100644
--- a/airavata-api/airavata-client-sdks/java-client-samples/src/main/java/org/apache/airavata/client/samples/CancelExperiments.java
+++ b/airavata-api/airavata-client-sdks/java-client-samples/src/main/java/org/apache/airavata/client/samples/CancelExperiments.java
@@ -49,7 +49,7 @@ public class CancelExperiments {
             String expeId = "echoExperiment_31c132fd-87ea-4781-803c-ae5f04a79baf";
             terminateExperiment(client,expeId);
 
-//            System.out.println("retrieved exp id : " + experiment.getExperimentID());
+//            System.out.println("retrieved exp id : " + experiment.getExperimentId());
         } catch (Exception e) {
             logger.error("Error while connecting with server", e.getMessage());
             e.printStackTrace();

http://git-wip-us.apache.org/repos/asf/airavata/blob/b376aa85/airavata-api/airavata-client-sdks/java-client-samples/src/main/java/org/apache/airavata/client/samples/CreateLaunchBES.java
----------------------------------------------------------------------
diff --git a/airavata-api/airavata-client-sdks/java-client-samples/src/main/java/org/apache/airavata/client/samples/CreateLaunchBES.java b/airavata-api/airavata-client-sdks/java-client-samples/src/main/java/org/apache/airavata/client/samples/CreateLaunchBES.java
index 44ebfc7..ec5a3f9 100644
--- a/airavata-api/airavata-client-sdks/java-client-samples/src/main/java/org/apache/airavata/client/samples/CreateLaunchBES.java
+++ b/airavata-api/airavata-client-sdks/java-client-samples/src/main/java/org/apache/airavata/client/samples/CreateLaunchBES.java
@@ -147,7 +147,7 @@ public class CreateLaunchBES {
             Thread.sleep(10000);
             for (String exId : experimentIds) {
                 Experiment experiment = airavataClient.getExperiment(exId);
-                System.out.println(experiment.getExperimentID() + " " + experiment.getExperimentStatus().getExperimentState().name());
+                System.out.println(experiment.getExperimentId() + " " + experiment.getExperimentStatus().getExperimentState().name());
             }
 
 
@@ -252,7 +252,7 @@ public class CreateLaunchBES {
                         userConfigurationData.setComputationalResourceScheduling(scheduling);
                         
                         userConfigurationData.setGenerateCert(false);
-                        userConfigurationData.setUserDN("");
+                        userConfigurationData.setUserDn("");
 
                         // set output directory 
                         AdvancedOutputDataHandling dataHandling = new AdvancedOutputDataHandling();
@@ -324,7 +324,7 @@ public class CreateLaunchBES {
                         userConfigurationData.setComputationalResourceScheduling(scheduling);
                         
                         userConfigurationData.setGenerateCert(true);
-                        userConfigurationData.setUserDN("CN=m.memon, O=Ultrascan Gateway, C=DE");
+                        userConfigurationData.setUserDn("CN=m.memon, O=Ultrascan Gateway, C=DE");
 
                         // set output directory 
                         AdvancedOutputDataHandling dataHandling = new AdvancedOutputDataHandling();

http://git-wip-us.apache.org/repos/asf/airavata/blob/b376aa85/airavata-api/airavata-client-sdks/java-client-samples/src/main/java/org/apache/airavata/client/samples/CreateLaunchExperiment.java
----------------------------------------------------------------------
diff --git a/airavata-api/airavata-client-sdks/java-client-samples/src/main/java/org/apache/airavata/client/samples/CreateLaunchExperiment.java b/airavata-api/airavata-client-sdks/java-client-samples/src/main/java/org/apache/airavata/client/samples/CreateLaunchExperiment.java
index ed85238..a616613 100644
--- a/airavata-api/airavata-client-sdks/java-client-samples/src/main/java/org/apache/airavata/client/samples/CreateLaunchExperiment.java
+++ b/airavata-api/airavata-client-sdks/java-client-samples/src/main/java/org/apache/airavata/client/samples/CreateLaunchExperiment.java
@@ -209,7 +209,7 @@ public class CreateLaunchExperiment {
                             &&!experiment.getExperimentStatus().getExperimentState().equals(ExperimentState.CANCELED)){
                         allNotFinished = true;
                     }
-                    System.out.println(experiment.getExperimentID() + " " + experiment.getExperimentStatus().getExperimentState().name());
+                    System.out.println(experiment.getExperimentId() + " " + experiment.getExperimentStatus().getExperimentState().name());
                 }
                 System.out.println("----------------------------------------------------");
                 Thread.sleep(10000);
@@ -348,7 +348,7 @@ public class CreateLaunchExperiment {
                         userConfigurationData.setComputationalResourceScheduling(scheduling);
                         
                         userConfigurationData.setGenerateCert(false);
-                        userConfigurationData.setUserDN("");
+                        userConfigurationData.setUserDn("");
 
                         // set output directory 
                         AdvancedOutputDataHandling dataHandling = new AdvancedOutputDataHandling();
@@ -405,7 +405,7 @@ public class CreateLaunchExperiment {
                         userConfigurationData.setComputationalResourceScheduling(scheduling);
                         
                         userConfigurationData.setGenerateCert(false);
-                        userConfigurationData.setUserDN("");
+                        userConfigurationData.setUserDn("");
 
                         // set output directory 
                         AdvancedOutputDataHandling dataHandling = new AdvancedOutputDataHandling();

http://git-wip-us.apache.org/repos/asf/airavata/blob/b376aa85/airavata-api/airavata-client-sdks/java-client-samples/src/main/java/org/apache/airavata/client/samples/CreateLaunchExperimentUS3.java
----------------------------------------------------------------------
diff --git a/airavata-api/airavata-client-sdks/java-client-samples/src/main/java/org/apache/airavata/client/samples/CreateLaunchExperimentUS3.java b/airavata-api/airavata-client-sdks/java-client-samples/src/main/java/org/apache/airavata/client/samples/CreateLaunchExperimentUS3.java
index bf82ed3..5b6e411 100644
--- a/airavata-api/airavata-client-sdks/java-client-samples/src/main/java/org/apache/airavata/client/samples/CreateLaunchExperimentUS3.java
+++ b/airavata-api/airavata-client-sdks/java-client-samples/src/main/java/org/apache/airavata/client/samples/CreateLaunchExperimentUS3.java
@@ -103,7 +103,7 @@ public class CreateLaunchExperimentUS3 {
 //            airavata.terminateExperiment(expId);
      
 //            Experiment experiment = airavata.getExperiment(expId);
-//            System.out.println("retrieved exp id : " + experiment.getExperimentID());
+//            System.out.println("retrieved exp id : " + experiment.getExperimentId());
         } catch (Exception e) {
             logger.error("Error while connecting with server", e.getMessage());
             e.printStackTrace();

http://git-wip-us.apache.org/repos/asf/airavata/blob/b376aa85/airavata-api/airavata-client-sdks/java-client-samples/src/main/java/org/apache/airavata/client/samples/TestCreateLaunchExperiment.java
----------------------------------------------------------------------
diff --git a/airavata-api/airavata-client-sdks/java-client-samples/src/main/java/org/apache/airavata/client/samples/TestCreateLaunchExperiment.java b/airavata-api/airavata-client-sdks/java-client-samples/src/main/java/org/apache/airavata/client/samples/TestCreateLaunchExperiment.java
index 8cfbd65..0dc422c 100644
--- a/airavata-api/airavata-client-sdks/java-client-samples/src/main/java/org/apache/airavata/client/samples/TestCreateLaunchExperiment.java
+++ b/airavata-api/airavata-client-sdks/java-client-samples/src/main/java/org/apache/airavata/client/samples/TestCreateLaunchExperiment.java
@@ -57,14 +57,14 @@ public class TestCreateLaunchExperiment {
 
             List<JobDetails> jobDetailsList = getJobDetails(airavata, "echoExperiment_14a83cee-5611-4e37-b90c-4444d28359b6");
             for (JobDetails job : jobDetailsList){
-//                System.out.println(experimentSummary.getExperimentID());
+//                System.out.println(experimentSummary.getExperimentId());
                 System.out.println("job description : " + job.getJobDescription());
 //                System.out.println(experimentSummary.getExperimentStatus().getExperimentState().toString());
             }
 
             List<DataTransferDetails> dataTransferDetails = getDataTransferDetails(airavata, "echoExperiment_6c32f45d-7755-4d1f-9915-69b9a6972770");
             for (DataTransferDetails dt : dataTransferDetails){
-//                System.out.println(experimentSummary.getExperimentID());
+//                System.out.println(experimentSummary.getExperimentId());
                 System.out.println("data transfer description "  + dt.getTransferDescription());
 //                System.out.println(experimentSummary.getExperimentStatus().getExperimentState().toString());
             }
@@ -82,7 +82,7 @@ public class TestCreateLaunchExperiment {
 //            List<Experiment> experiments = getExperimentsForUser(airavata, "admin");
 //            System.out.println("Experiment count : " + experiments.size());
 //            for (Experiment ex : experiments){
-//                System.out.println(ex.getExperimentID());
+//                System.out.println(ex.getExperimentId());
 //            }
 
         } catch (Exception e) {

http://git-wip-us.apache.org/repos/asf/airavata/blob/b376aa85/airavata-api/airavata-data-models/src/main/java/org/apache/airavata/model/workspace/Project.java
----------------------------------------------------------------------
diff --git a/airavata-api/airavata-data-models/src/main/java/org/apache/airavata/model/workspace/Project.java b/airavata-api/airavata-data-models/src/main/java/org/apache/airavata/model/workspace/Project.java
index 230ec0a..0e8d077 100644
--- a/airavata-api/airavata-data-models/src/main/java/org/apache/airavata/model/workspace/Project.java
+++ b/airavata-api/airavata-data-models/src/main/java/org/apache/airavata/model/workspace/Project.java
@@ -52,7 +52,7 @@ import org.slf4j.LoggerFactory;
 @SuppressWarnings("all") public class Project implements org.apache.thrift.TBase<Project, Project._Fields>, java.io.Serializable, Cloneable, Comparable<Project> {
   private static final org.apache.thrift.protocol.TStruct STRUCT_DESC = new org.apache.thrift.protocol.TStruct("Project");
 
-  private static final org.apache.thrift.protocol.TField PROJECT_ID_FIELD_DESC = new org.apache.thrift.protocol.TField("projectID", org.apache.thrift.protocol.TType.STRING, (short)1);
+  private static final org.apache.thrift.protocol.TField PROJECT_ID_FIELD_DESC = new org.apache.thrift.protocol.TField("projectId", org.apache.thrift.protocol.TType.STRING, (short)1);
   private static final org.apache.thrift.protocol.TField OWNER_FIELD_DESC = new org.apache.thrift.protocol.TField("owner", org.apache.thrift.protocol.TType.STRING, (short)2);
   private static final org.apache.thrift.protocol.TField NAME_FIELD_DESC = new org.apache.thrift.protocol.TField("name", org.apache.thrift.protocol.TType.STRING, (short)3);
   private static final org.apache.thrift.protocol.TField DESCRIPTION_FIELD_DESC = new org.apache.thrift.protocol.TField("description", org.apache.thrift.protocol.TType.STRING, (short)4);
@@ -66,7 +66,7 @@ import org.slf4j.LoggerFactory;
     schemes.put(TupleScheme.class, new ProjectTupleSchemeFactory());
   }
 
-  private String projectID; // required
+  private String projectId; // required
   private String owner; // required
   private String name; // required
   private String description; // optional
@@ -76,7 +76,7 @@ import org.slf4j.LoggerFactory;
 
   /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
   @SuppressWarnings("all") public enum _Fields implements org.apache.thrift.TFieldIdEnum {
-    PROJECT_ID((short)1, "projectID"),
+    PROJECT_ID((short)1, "projectId"),
     OWNER((short)2, "owner"),
     NAME((short)3, "name"),
     DESCRIPTION((short)4, "description"),
@@ -157,7 +157,7 @@ import org.slf4j.LoggerFactory;
   public static final Map<_Fields, org.apache.thrift.meta_data.FieldMetaData> metaDataMap;
   static {
     Map<_Fields, org.apache.thrift.meta_data.FieldMetaData> tmpMap = new EnumMap<_Fields, org.apache.thrift.meta_data.FieldMetaData>(_Fields.class);
-    tmpMap.put(_Fields.PROJECT_ID, new org.apache.thrift.meta_data.FieldMetaData("projectID", org.apache.thrift.TFieldRequirementType.REQUIRED, 
+    tmpMap.put(_Fields.PROJECT_ID, new org.apache.thrift.meta_data.FieldMetaData("projectId", org.apache.thrift.TFieldRequirementType.REQUIRED, 
         new org.apache.thrift.meta_data.FieldValueMetaData(org.apache.thrift.protocol.TType.STRING)));
     tmpMap.put(_Fields.OWNER, new org.apache.thrift.meta_data.FieldMetaData("owner", org.apache.thrift.TFieldRequirementType.REQUIRED, 
         new org.apache.thrift.meta_data.FieldValueMetaData(org.apache.thrift.protocol.TType.STRING)));
@@ -178,17 +178,17 @@ import org.slf4j.LoggerFactory;
   }
 
   public Project() {
-    this.projectID = "DEFAULT";
+    this.projectId = "DEFAULT";
 
   }
 
   public Project(
-    String projectID,
+    String projectId,
     String owner,
     String name)
   {
     this();
-    this.projectID = projectID;
+    this.projectId = projectId;
     this.owner = owner;
     this.name = name;
   }
@@ -198,8 +198,8 @@ import org.slf4j.LoggerFactory;
    */
   public Project(Project other) {
     __isset_bitfield = other.__isset_bitfield;
-    if (other.isSetProjectID()) {
-      this.projectID = other.projectID;
+    if (other.isSetProjectId()) {
+      this.projectId = other.projectId;
     }
     if (other.isSetOwner()) {
       this.owner = other.owner;
@@ -227,7 +227,7 @@ import org.slf4j.LoggerFactory;
 
   @Override
   public void clear() {
-    this.projectID = "DEFAULT";
+    this.projectId = "DEFAULT";
 
     this.owner = null;
     this.name = null;
@@ -238,26 +238,26 @@ import org.slf4j.LoggerFactory;
     this.sharedGroups = null;
   }
 
-  public String getProjectID() {
-    return this.projectID;
+  public String getProjectId() {
+    return this.projectId;
   }
 
-  public void setProjectID(String projectID) {
-    this.projectID = projectID;
+  public void setProjectId(String projectId) {
+    this.projectId = projectId;
   }
 
-  public void unsetProjectID() {
-    this.projectID = null;
+  public void unsetProjectId() {
+    this.projectId = null;
   }
 
-  /** Returns true if field projectID is set (has been assigned a value) and false otherwise */
-  public boolean isSetProjectID() {
-    return this.projectID != null;
+  /** Returns true if field projectId is set (has been assigned a value) and false otherwise */
+  public boolean isSetProjectId() {
+    return this.projectId != null;
   }
 
-  public void setProjectIDIsSet(boolean value) {
+  public void setProjectIdIsSet(boolean value) {
     if (!value) {
-      this.projectID = null;
+      this.projectId = null;
     }
   }
 
@@ -432,9 +432,9 @@ import org.slf4j.LoggerFactory;
     switch (field) {
     case PROJECT_ID:
       if (value == null) {
-        unsetProjectID();
+        unsetProjectId();
       } else {
-        setProjectID((String)value);
+        setProjectId((String)value);
       }
       break;
 
@@ -492,7 +492,7 @@ import org.slf4j.LoggerFactory;
   public Object getFieldValue(_Fields field) {
     switch (field) {
     case PROJECT_ID:
-      return getProjectID();
+      return getProjectId();
 
     case OWNER:
       return getOwner();
@@ -524,7 +524,7 @@ import org.slf4j.LoggerFactory;
 
     switch (field) {
     case PROJECT_ID:
-      return isSetProjectID();
+      return isSetProjectId();
     case OWNER:
       return isSetOwner();
     case NAME:
@@ -554,12 +554,12 @@ import org.slf4j.LoggerFactory;
     if (that == null)
       return false;
 
-    boolean this_present_projectID = true && this.isSetProjectID();
-    boolean that_present_projectID = true && that.isSetProjectID();
-    if (this_present_projectID || that_present_projectID) {
-      if (!(this_present_projectID && that_present_projectID))
+    boolean this_present_projectId = true && this.isSetProjectId();
+    boolean that_present_projectId = true && that.isSetProjectId();
+    if (this_present_projectId || that_present_projectId) {
+      if (!(this_present_projectId && that_present_projectId))
         return false;
-      if (!this.projectID.equals(that.projectID))
+      if (!this.projectId.equals(that.projectId))
         return false;
     }
 
@@ -633,12 +633,12 @@ import org.slf4j.LoggerFactory;
 
     int lastComparison = 0;
 
-    lastComparison = Boolean.valueOf(isSetProjectID()).compareTo(other.isSetProjectID());
+    lastComparison = Boolean.valueOf(isSetProjectId()).compareTo(other.isSetProjectId());
     if (lastComparison != 0) {
       return lastComparison;
     }
-    if (isSetProjectID()) {
-      lastComparison = org.apache.thrift.TBaseHelper.compareTo(this.projectID, other.projectID);
+    if (isSetProjectId()) {
+      lastComparison = org.apache.thrift.TBaseHelper.compareTo(this.projectId, other.projectId);
       if (lastComparison != 0) {
         return lastComparison;
       }
@@ -723,11 +723,11 @@ import org.slf4j.LoggerFactory;
     StringBuilder sb = new StringBuilder("Project(");
     boolean first = true;
 
-    sb.append("projectID:");
-    if (this.projectID == null) {
+    sb.append("projectId:");
+    if (this.projectId == null) {
       sb.append("null");
     } else {
-      sb.append(this.projectID);
+      sb.append(this.projectId);
     }
     first = false;
     if (!first) sb.append(", ");
@@ -788,8 +788,8 @@ import org.slf4j.LoggerFactory;
 
   public void validate() throws org.apache.thrift.TException {
     // check for required fields
-    if (!isSetProjectID()) {
-      throw new org.apache.thrift.protocol.TProtocolException("Required field 'projectID' is unset! Struct:" + toString());
+    if (!isSetProjectId()) {
+      throw new org.apache.thrift.protocol.TProtocolException("Required field 'projectId' is unset! Struct:" + toString());
     }
 
     if (!isSetOwner()) {
@@ -841,8 +841,8 @@ import org.slf4j.LoggerFactory;
         switch (schemeField.id) {
           case 1: // PROJECT_ID
             if (schemeField.type == org.apache.thrift.protocol.TType.STRING) {
-              struct.projectID = iprot.readString();
-              struct.setProjectIDIsSet(true);
+              struct.projectId = iprot.readString();
+              struct.setProjectIdIsSet(true);
             } else { 
               org.apache.thrift.protocol.TProtocolUtil.skip(iprot, schemeField.type);
             }
@@ -928,9 +928,9 @@ import org.slf4j.LoggerFactory;
       struct.validate();
 
       oprot.writeStructBegin(STRUCT_DESC);
-      if (struct.projectID != null) {
+      if (struct.projectId != null) {
         oprot.writeFieldBegin(PROJECT_ID_FIELD_DESC);
-        oprot.writeString(struct.projectID);
+        oprot.writeString(struct.projectId);
         oprot.writeFieldEnd();
       }
       if (struct.owner != null) {
@@ -1000,7 +1000,7 @@ import org.slf4j.LoggerFactory;
     @Override
     public void write(org.apache.thrift.protocol.TProtocol prot, Project struct) throws org.apache.thrift.TException {
       TTupleProtocol oprot = (TTupleProtocol) prot;
-      oprot.writeString(struct.projectID);
+      oprot.writeString(struct.projectId);
       oprot.writeString(struct.owner);
       oprot.writeString(struct.name);
       BitSet optionals = new BitSet();
@@ -1046,8 +1046,8 @@ import org.slf4j.LoggerFactory;
     @Override
     public void read(org.apache.thrift.protocol.TProtocol prot, Project struct) throws org.apache.thrift.TException {
       TTupleProtocol iprot = (TTupleProtocol) prot;
-      struct.projectID = iprot.readString();
-      struct.setProjectIDIsSet(true);
+      struct.projectId = iprot.readString();
+      struct.setProjectIdIsSet(true);
       struct.owner = iprot.readString();
       struct.setOwnerIsSet(true);
       struct.name = iprot.readString();

http://git-wip-us.apache.org/repos/asf/airavata/blob/b376aa85/airavata-api/airavata-data-models/src/main/java/org/apache/airavata/model/workspace/experiment/ComputationalResourceScheduling.java
----------------------------------------------------------------------
diff --git a/airavata-api/airavata-data-models/src/main/java/org/apache/airavata/model/workspace/experiment/DataTransferDetails.java b/airavata-api/airavata-data-models/src/main/java/org/apache/airavata/model/workspace/experiment/DataTransferDetails.java
index 94751c7..ebc2d0e 100644
--- a/airavata-api/airavata-data-models/src/main/java/org/apache/airavata/model/workspace/experiment/DataTransferDetails.java
+++ b/airavata-api/airavata-data-models/src/main/java/org/apache/airavata/model/workspace/experiment/DataTransferDetails.java
@@ -23,36 +23,19 @@
  */
 package org.apache.airavata.model.workspace.experiment;
 
+import org.apache.thrift.EncodingUtils;
+import org.apache.thrift.protocol.TTupleProtocol;
 import org.apache.thrift.scheme.IScheme;
 import org.apache.thrift.scheme.SchemeFactory;
 import org.apache.thrift.scheme.StandardScheme;
-
 import org.apache.thrift.scheme.TupleScheme;
-import org.apache.thrift.protocol.TTupleProtocol;
-import org.apache.thrift.protocol.TProtocolException;
-import org.apache.thrift.EncodingUtils;
-import org.apache.thrift.TException;
-import org.apache.thrift.async.AsyncMethodCallback;
-import org.apache.thrift.server.AbstractNonblockingServer.*;
-import java.util.List;
-import java.util.ArrayList;
-import java.util.Map;
-import java.util.HashMap;
-import java.util.EnumMap;
-import java.util.Set;
-import java.util.HashSet;
-import java.util.EnumSet;
-import java.util.Collections;
-import java.util.BitSet;
-import java.nio.ByteBuffer;
-import java.util.Arrays;
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
+
+import java.util.*;
 
 @SuppressWarnings("all") public class DataTransferDetails implements org.apache.thrift.TBase<DataTransferDetails, DataTransferDetails._Fields>, java.io.Serializable, Cloneable, Comparable<DataTransferDetails> {
   private static final org.apache.thrift.protocol.TStruct STRUCT_DESC = new org.apache.thrift.protocol.TStruct("DataTransferDetails");
 
-  private static final org.apache.thrift.protocol.TField TRANSFER_ID_FIELD_DESC = new org.apache.thrift.protocol.TField("transferID", org.apache.thrift.protocol.TType.STRING, (short)1);
+  private static final org.apache.thrift.protocol.TField TRANSFER_ID_FIELD_DESC = new org.apache.thrift.protocol.TField("transferId", org.apache.thrift.protocol.TType.STRING, (short)1);
   private static final org.apache.thrift.protocol.TField CREATION_TIME_FIELD_DESC = new org.apache.thrift.protocol.TField("creationTime", org.apache.thrift.protocol.TType.I64, (short)2);
   private static final org.apache.thrift.protocol.TField TRANSFER_DESCRIPTION_FIELD_DESC = new org.apache.thrift.protocol.TField("transferDescription", org.apache.thrift.protocol.TType.STRING, (short)3);
   private static final org.apache.thrift.protocol.TField TRANSFER_STATUS_FIELD_DESC = new org.apache.thrift.protocol.TField("transferStatus", org.apache.thrift.protocol.TType.STRUCT, (short)4);
@@ -63,14 +46,14 @@ import org.slf4j.LoggerFactory;
     schemes.put(TupleScheme.class, new DataTransferDetailsTupleSchemeFactory());
   }
 
-  private String transferID; // required
+  private String transferId; // required
   private long creationTime; // optional
   private String transferDescription; // required
   private TransferStatus transferStatus; // optional
 
   /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
   @SuppressWarnings("all") public enum _Fields implements org.apache.thrift.TFieldIdEnum {
-    TRANSFER_ID((short)1, "transferID"),
+    TRANSFER_ID((short)1, "transferId"),
     CREATION_TIME((short)2, "creationTime"),
     TRANSFER_DESCRIPTION((short)3, "transferDescription"),
     TRANSFER_STATUS((short)4, "transferStatus");
@@ -142,7 +125,7 @@ import org.slf4j.LoggerFactory;
   public static final Map<_Fields, org.apache.thrift.meta_data.FieldMetaData> metaDataMap;
   static {
     Map<_Fields, org.apache.thrift.meta_data.FieldMetaData> tmpMap = new EnumMap<_Fields, org.apache.thrift.meta_data.FieldMetaData>(_Fields.class);
-    tmpMap.put(_Fields.TRANSFER_ID, new org.apache.thrift.meta_data.FieldMetaData("transferID", org.apache.thrift.TFieldRequirementType.REQUIRED, 
+    tmpMap.put(_Fields.TRANSFER_ID, new org.apache.thrift.meta_data.FieldMetaData("transferId", org.apache.thrift.TFieldRequirementType.REQUIRED, 
         new org.apache.thrift.meta_data.FieldValueMetaData(org.apache.thrift.protocol.TType.STRING)));
     tmpMap.put(_Fields.CREATION_TIME, new org.apache.thrift.meta_data.FieldMetaData("creationTime", org.apache.thrift.TFieldRequirementType.OPTIONAL, 
         new org.apache.thrift.meta_data.FieldValueMetaData(org.apache.thrift.protocol.TType.I64)));
@@ -155,16 +138,16 @@ import org.slf4j.LoggerFactory;
   }
 
   public DataTransferDetails() {
-    this.transferID = "DO_NOT_SET_AT_CLIENTS";
+    this.transferId = "DO_NOT_SET_AT_CLIENTS";
 
   }
 
   public DataTransferDetails(
-    String transferID,
+    String transferId,
     String transferDescription)
   {
     this();
-    this.transferID = transferID;
+    this.transferId = transferId;
     this.transferDescription = transferDescription;
   }
 
@@ -173,8 +156,8 @@ import org.slf4j.LoggerFactory;
    */
   public DataTransferDetails(DataTransferDetails other) {
     __isset_bitfield = other.__isset_bitfield;
-    if (other.isSetTransferID()) {
-      this.transferID = other.transferID;
+    if (other.isSetTransferId()) {
+      this.transferId = other.transferId;
     }
     this.creationTime = other.creationTime;
     if (other.isSetTransferDescription()) {
@@ -191,7 +174,7 @@ import org.slf4j.LoggerFactory;
 
   @Override
   public void clear() {
-    this.transferID = "DO_NOT_SET_AT_CLIENTS";
+    this.transferId = "DO_NOT_SET_AT_CLIENTS";
 
     setCreationTimeIsSet(false);
     this.creationTime = 0;
@@ -199,26 +182,26 @@ import org.slf4j.LoggerFactory;
     this.transferStatus = null;
   }
 
-  public String getTransferID() {
-    return this.transferID;
+  public String getTransferId() {
+    return this.transferId;
   }
 
-  public void setTransferID(String transferID) {
-    this.transferID = transferID;
+  public void setTransferId(String transferId) {
+    this.transferId = transferId;
   }
 
-  public void unsetTransferID() {
-    this.transferID = null;
+  public void unsetTransferId() {
+    this.transferId = null;
   }
 
-  /** Returns true if field transferID is set (has been assigned a value) and false otherwise */
-  public boolean isSetTransferID() {
-    return this.transferID != null;
+  /** Returns true if field transferId is set (has been assigned a value) and false otherwise */
+  public boolean isSetTransferId() {
+    return this.transferId != null;
   }
 
-  public void setTransferIDIsSet(boolean value) {
+  public void setTransferIdIsSet(boolean value) {
     if (!value) {
-      this.transferID = null;
+      this.transferId = null;
     }
   }
 
@@ -294,9 +277,9 @@ import org.slf4j.LoggerFactory;
     switch (field) {
     case TRANSFER_ID:
       if (value == null) {
-        unsetTransferID();
+        unsetTransferId();
       } else {
-        setTransferID((String)value);
+        setTransferId((String)value);
       }
       break;
 
@@ -330,7 +313,7 @@ import org.slf4j.LoggerFactory;
   public Object getFieldValue(_Fields field) {
     switch (field) {
     case TRANSFER_ID:
-      return getTransferID();
+      return getTransferId();
 
     case CREATION_TIME:
       return Long.valueOf(getCreationTime());
@@ -353,7 +336,7 @@ import org.slf4j.LoggerFactory;
 
     switch (field) {
     case TRANSFER_ID:
-      return isSetTransferID();
+      return isSetTransferId();
     case CREATION_TIME:
       return isSetCreationTime();
     case TRANSFER_DESCRIPTION:
@@ -377,12 +360,12 @@ import org.slf4j.LoggerFactory;
     if (that == null)
       return false;
 
-    boolean this_present_transferID = true && this.isSetTransferID();
-    boolean that_present_transferID = true && that.isSetTransferID();
-    if (this_present_transferID || that_present_transferID) {
-      if (!(this_present_transferID && that_present_transferID))
+    boolean this_present_transferId = true && this.isSetTransferId();
+    boolean that_present_transferId = true && that.isSetTransferId();
+    if (this_present_transferId || that_present_transferId) {
+      if (!(this_present_transferId && that_present_transferId))
         return false;
-      if (!this.transferID.equals(that.transferID))
+      if (!this.transferId.equals(that.transferId))
         return false;
     }
 
@@ -429,12 +412,12 @@ import org.slf4j.LoggerFactory;
 
     int lastComparison = 0;
 
-    lastComparison = Boolean.valueOf(isSetTransferID()).compareTo(other.isSetTransferID());
+    lastComparison = Boolean.valueOf(isSetTransferId()).compareTo(other.isSetTransferId());
     if (lastComparison != 0) {
       return lastComparison;
     }
-    if (isSetTransferID()) {
-      lastComparison = org.apache.thrift.TBaseHelper.compareTo(this.transferID, other.transferID);
+    if (isSetTransferId()) {
+      lastComparison = org.apache.thrift.TBaseHelper.compareTo(this.transferId, other.transferId);
       if (lastComparison != 0) {
         return lastComparison;
       }
@@ -489,11 +472,11 @@ import org.slf4j.LoggerFactory;
     StringBuilder sb = new StringBuilder("DataTransferDetails(");
     boolean first = true;
 
-    sb.append("transferID:");
-    if (this.transferID == null) {
+    sb.append("transferId:");
+    if (this.transferId == null) {
       sb.append("null");
     } else {
-      sb.append(this.transferID);
+      sb.append(this.transferId);
     }
     first = false;
     if (isSetCreationTime()) {
@@ -526,8 +509,8 @@ import org.slf4j.LoggerFactory;
 
   public void validate() throws org.apache.thrift.TException {
     // check for required fields
-    if (!isSetTransferID()) {
-      throw new org.apache.thrift.protocol.TProtocolException("Required field 'transferID' is unset! Struct:" + toString());
+    if (!isSetTransferId()) {
+      throw new org.apache.thrift.protocol.TProtocolException("Required field 'transferId' is unset! Struct:" + toString());
     }
 
     if (!isSetTransferDescription()) {
@@ -578,8 +561,8 @@ import org.slf4j.LoggerFactory;
         switch (schemeField.id) {
           case 1: // TRANSFER_ID
             if (schemeField.type == org.apache.thrift.protocol.TType.STRING) {
-              struct.transferID = iprot.readString();
-              struct.setTransferIDIsSet(true);
+              struct.transferId = iprot.readString();
+              struct.setTransferIdIsSet(true);
             } else { 
               org.apache.thrift.protocol.TProtocolUtil.skip(iprot, schemeField.type);
             }
@@ -622,9 +605,9 @@ import org.slf4j.LoggerFactory;
       struct.validate();
 
       oprot.writeStructBegin(STRUCT_DESC);
-      if (struct.transferID != null) {
+      if (struct.transferId != null) {
         oprot.writeFieldBegin(TRANSFER_ID_FIELD_DESC);
-        oprot.writeString(struct.transferID);
+        oprot.writeString(struct.transferId);
         oprot.writeFieldEnd();
       }
       if (struct.isSetCreationTime()) {
@@ -661,7 +644,7 @@ import org.slf4j.LoggerFactory;
     @Override
     public void write(org.apache.thrift.protocol.TProtocol prot, DataTransferDetails struct) throws org.apache.thrift.TException {
       TTupleProtocol oprot = (TTupleProtocol) prot;
-      oprot.writeString(struct.transferID);
+      oprot.writeString(struct.transferId);
       oprot.writeString(struct.transferDescription);
       BitSet optionals = new BitSet();
       if (struct.isSetCreationTime()) {
@@ -682,8 +665,8 @@ import org.slf4j.LoggerFactory;
     @Override
     public void read(org.apache.thrift.protocol.TProtocol prot, DataTransferDetails struct) throws org.apache.thrift.TException {
       TTupleProtocol iprot = (TTupleProtocol) prot;
-      struct.transferID = iprot.readString();
-      struct.setTransferIDIsSet(true);
+      struct.transferId = iprot.readString();
+      struct.setTransferIdIsSet(true);
       struct.transferDescription = iprot.readString();
       struct.setTransferDescriptionIsSet(true);
       BitSet incoming = iprot.readBitSet(2);

http://git-wip-us.apache.org/repos/asf/airavata/blob/b376aa85/airavata-api/airavata-data-models/src/main/java/org/apache/airavata/model/workspace/experiment/ErrorDetails.java
----------------------------------------------------------------------
diff --git a/airavata-api/airavata-data-models/src/main/java/org/apache/airavata/model/workspace/experiment/ErrorDetails.java b/airavata-api/airavata-data-models/src/main/java/org/apache/airavata/model/workspace/experiment/ErrorDetails.java
index ce1f74a..f9918ff 100644
--- a/airavata-api/airavata-data-models/src/main/java/org/apache/airavata/model/workspace/experiment/ErrorDetails.java
+++ b/airavata-api/airavata-data-models/src/main/java/org/apache/airavata/model/workspace/experiment/ErrorDetails.java
@@ -52,7 +52,7 @@ import org.slf4j.LoggerFactory;
 @SuppressWarnings("all") public class ErrorDetails implements org.apache.thrift.TBase<ErrorDetails, ErrorDetails._Fields>, java.io.Serializable, Cloneable, Comparable<ErrorDetails> {
   private static final org.apache.thrift.protocol.TStruct STRUCT_DESC = new org.apache.thrift.protocol.TStruct("ErrorDetails");
 
-  private static final org.apache.thrift.protocol.TField ERROR_ID_FIELD_DESC = new org.apache.thrift.protocol.TField("errorID", org.apache.thrift.protocol.TType.STRING, (short)1);
+  private static final org.apache.thrift.protocol.TField ERROR_ID_FIELD_DESC = new org.apache.thrift.protocol.TField("errorId", org.apache.thrift.protocol.TType.STRING, (short)1);
   private static final org.apache.thrift.protocol.TField CREATION_TIME_FIELD_DESC = new org.apache.thrift.protocol.TField("creationTime", org.apache.thrift.protocol.TType.I64, (short)2);
   private static final org.apache.thrift.protocol.TField ACTUAL_ERROR_MESSAGE_FIELD_DESC = new org.apache.thrift.protocol.TField("actualErrorMessage", org.apache.thrift.protocol.TType.STRING, (short)3);
   private static final org.apache.thrift.protocol.TField USER_FRIENDLY_MESSAGE_FIELD_DESC = new org.apache.thrift.protocol.TField("userFriendlyMessage", org.apache.thrift.protocol.TType.STRING, (short)4);
@@ -68,7 +68,7 @@ import org.slf4j.LoggerFactory;
     schemes.put(TupleScheme.class, new ErrorDetailsTupleSchemeFactory());
   }
 
-  private String errorID; // required
+  private String errorId; // required
   private long creationTime; // optional
   private String actualErrorMessage; // optional
   private String userFriendlyMessage; // optional
@@ -80,7 +80,7 @@ import org.slf4j.LoggerFactory;
 
   /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
   @SuppressWarnings("all") public enum _Fields implements org.apache.thrift.TFieldIdEnum {
-    ERROR_ID((short)1, "errorID"),
+    ERROR_ID((short)1, "errorId"),
     CREATION_TIME((short)2, "creationTime"),
     ACTUAL_ERROR_MESSAGE((short)3, "actualErrorMessage"),
     USER_FRIENDLY_MESSAGE((short)4, "userFriendlyMessage"),
@@ -180,7 +180,7 @@ import org.slf4j.LoggerFactory;
   public static final Map<_Fields, org.apache.thrift.meta_data.FieldMetaData> metaDataMap;
   static {
     Map<_Fields, org.apache.thrift.meta_data.FieldMetaData> tmpMap = new EnumMap<_Fields, org.apache.thrift.meta_data.FieldMetaData>(_Fields.class);
-    tmpMap.put(_Fields.ERROR_ID, new org.apache.thrift.meta_data.FieldMetaData("errorID", org.apache.thrift.TFieldRequirementType.REQUIRED, 
+    tmpMap.put(_Fields.ERROR_ID, new org.apache.thrift.meta_data.FieldMetaData("errorId", org.apache.thrift.TFieldRequirementType.REQUIRED, 
         new org.apache.thrift.meta_data.FieldValueMetaData(org.apache.thrift.protocol.TType.STRING)));
     tmpMap.put(_Fields.CREATION_TIME, new org.apache.thrift.meta_data.FieldMetaData("creationTime", org.apache.thrift.TFieldRequirementType.OPTIONAL, 
         new org.apache.thrift.meta_data.FieldValueMetaData(org.apache.thrift.protocol.TType.I64)));
@@ -204,17 +204,17 @@ import org.slf4j.LoggerFactory;
   }
 
   public ErrorDetails() {
-    this.errorID = "DO_NOT_SET_AT_CLIENTS";
+    this.errorId = "DO_NOT_SET_AT_CLIENTS";
 
     this.transientOrPersistent = false;
 
   }
 
   public ErrorDetails(
-    String errorID)
+    String errorId)
   {
     this();
-    this.errorID = errorID;
+    this.errorId = errorId;
   }
 
   /**
@@ -222,8 +222,8 @@ import org.slf4j.LoggerFactory;
    */
   public ErrorDetails(ErrorDetails other) {
     __isset_bitfield = other.__isset_bitfield;
-    if (other.isSetErrorID()) {
-      this.errorID = other.errorID;
+    if (other.isSetErrorId()) {
+      this.errorId = other.errorId;
     }
     this.creationTime = other.creationTime;
     if (other.isSetActualErrorMessage()) {
@@ -254,7 +254,7 @@ import org.slf4j.LoggerFactory;
 
   @Override
   public void clear() {
-    this.errorID = "DO_NOT_SET_AT_CLIENTS";
+    this.errorId = "DO_NOT_SET_AT_CLIENTS";
 
     setCreationTimeIsSet(false);
     this.creationTime = 0;
@@ -268,26 +268,26 @@ import org.slf4j.LoggerFactory;
     this.rootCauseErrorIdList = null;
   }
 
-  public String getErrorID() {
-    return this.errorID;
+  public String getErrorId() {
+    return this.errorId;
   }
 
-  public void setErrorID(String errorID) {
-    this.errorID = errorID;
+  public void setErrorId(String errorId) {
+    this.errorId = errorId;
   }
 
-  public void unsetErrorID() {
-    this.errorID = null;
+  public void unsetErrorId() {
+    this.errorId = null;
   }
 
-  /** Returns true if field errorID is set (has been assigned a value) and false otherwise */
-  public boolean isSetErrorID() {
-    return this.errorID != null;
+  /** Returns true if field errorId is set (has been assigned a value) and false otherwise */
+  public boolean isSetErrorId() {
+    return this.errorId != null;
   }
 
-  public void setErrorIDIsSet(boolean value) {
+  public void setErrorIdIsSet(boolean value) {
     if (!value) {
-      this.errorID = null;
+      this.errorId = null;
     }
   }
 
@@ -516,9 +516,9 @@ import org.slf4j.LoggerFactory;
     switch (field) {
     case ERROR_ID:
       if (value == null) {
-        unsetErrorID();
+        unsetErrorId();
       } else {
-        setErrorID((String)value);
+        setErrorId((String)value);
       }
       break;
 
@@ -592,7 +592,7 @@ import org.slf4j.LoggerFactory;
   public Object getFieldValue(_Fields field) {
     switch (field) {
     case ERROR_ID:
-      return getErrorID();
+      return getErrorId();
 
     case CREATION_TIME:
       return Long.valueOf(getCreationTime());
@@ -630,7 +630,7 @@ import org.slf4j.LoggerFactory;
 
     switch (field) {
     case ERROR_ID:
-      return isSetErrorID();
+      return isSetErrorId();
     case CREATION_TIME:
       return isSetCreationTime();
     case ACTUAL_ERROR_MESSAGE:
@@ -664,12 +664,12 @@ import org.slf4j.LoggerFactory;
     if (that == null)
       return false;
 
-    boolean this_present_errorID = true && this.isSetErrorID();
-    boolean that_present_errorID = true && that.isSetErrorID();
-    if (this_present_errorID || that_present_errorID) {
-      if (!(this_present_errorID && that_present_errorID))
+    boolean this_present_errorId = true && this.isSetErrorId();
+    boolean that_present_errorId = true && that.isSetErrorId();
+    if (this_present_errorId || that_present_errorId) {
+      if (!(this_present_errorId && that_present_errorId))
         return false;
-      if (!this.errorID.equals(that.errorID))
+      if (!this.errorId.equals(that.errorId))
         return false;
     }
 
@@ -761,12 +761,12 @@ import org.slf4j.LoggerFactory;
 
     int lastComparison = 0;
 
-    lastComparison = Boolean.valueOf(isSetErrorID()).compareTo(other.isSetErrorID());
+    lastComparison = Boolean.valueOf(isSetErrorId()).compareTo(other.isSetErrorId());
     if (lastComparison != 0) {
       return lastComparison;
     }
-    if (isSetErrorID()) {
-      lastComparison = org.apache.thrift.TBaseHelper.compareTo(this.errorID, other.errorID);
+    if (isSetErrorId()) {
+      lastComparison = org.apache.thrift.TBaseHelper.compareTo(this.errorId, other.errorId);
       if (lastComparison != 0) {
         return lastComparison;
       }
@@ -871,11 +871,11 @@ import org.slf4j.LoggerFactory;
     StringBuilder sb = new StringBuilder("ErrorDetails(");
     boolean first = true;
 
-    sb.append("errorID:");
-    if (this.errorID == null) {
+    sb.append("errorId:");
+    if (this.errorId == null) {
       sb.append("null");
     } else {
-      sb.append(this.errorID);
+      sb.append(this.errorId);
     }
     first = false;
     if (isSetCreationTime()) {
@@ -956,8 +956,8 @@ import org.slf4j.LoggerFactory;
 
   public void validate() throws org.apache.thrift.TException {
     // check for required fields
-    if (!isSetErrorID()) {
-      throw new org.apache.thrift.protocol.TProtocolException("Required field 'errorID' is unset! Struct:" + toString());
+    if (!isSetErrorId()) {
+      throw new org.apache.thrift.protocol.TProtocolException("Required field 'errorId' is unset! Struct:" + toString());
     }
 
     // check for sub-struct validity
@@ -1001,8 +1001,8 @@ import org.slf4j.LoggerFactory;
         switch (schemeField.id) {
           case 1: // ERROR_ID
             if (schemeField.type == org.apache.thrift.protocol.TType.STRING) {
-              struct.errorID = iprot.readString();
-              struct.setErrorIDIsSet(true);
+              struct.errorId = iprot.readString();
+              struct.setErrorIdIsSet(true);
             } else { 
               org.apache.thrift.protocol.TProtocolUtil.skip(iprot, schemeField.type);
             }
@@ -1094,9 +1094,9 @@ import org.slf4j.LoggerFactory;
       struct.validate();
 
       oprot.writeStructBegin(STRUCT_DESC);
-      if (struct.errorID != null) {
+      if (struct.errorId != null) {
         oprot.writeFieldBegin(ERROR_ID_FIELD_DESC);
-        oprot.writeString(struct.errorID);
+        oprot.writeString(struct.errorId);
         oprot.writeFieldEnd();
       }
       if (struct.isSetCreationTime()) {
@@ -1175,7 +1175,7 @@ import org.slf4j.LoggerFactory;
     @Override
     public void write(org.apache.thrift.protocol.TProtocol prot, ErrorDetails struct) throws org.apache.thrift.TException {
       TTupleProtocol oprot = (TTupleProtocol) prot;
-      oprot.writeString(struct.errorID);
+      oprot.writeString(struct.errorId);
       BitSet optionals = new BitSet();
       if (struct.isSetCreationTime()) {
         optionals.set(0);
@@ -1237,8 +1237,8 @@ import org.slf4j.LoggerFactory;
     @Override
     public void read(org.apache.thrift.protocol.TProtocol prot, ErrorDetails struct) throws org.apache.thrift.TException {
       TTupleProtocol iprot = (TTupleProtocol) prot;
-      struct.errorID = iprot.readString();
-      struct.setErrorIDIsSet(true);
+      struct.errorId = iprot.readString();
+      struct.setErrorIdIsSet(true);
       BitSet incoming = iprot.readBitSet(8);
       if (incoming.get(0)) {
         struct.creationTime = iprot.readI64();
diff --git a/airavata-api/airavata-data-models/src/main/java/org/apache/airavata/model/workspace/experiment/ComputationalResourceScheduling.java b/airavata-api/airavata-data-models/src/main/java/org/apache/airavata/model/workspace/experiment/ComputationalResourceScheduling.java
index 51ef625..b4a7e4e 100644
--- a/airavata-api/airavata-data-models/src/main/java/org/apache/airavata/model/workspace/experiment/ComputationalResourceScheduling.java
+++ b/airavata-api/airavata-data-models/src/main/java/org/apache/airavata/model/workspace/experiment/ComputationalResourceScheduling.java
@@ -57,7 +57,7 @@ import org.slf4j.LoggerFactory;
   private static final org.apache.thrift.protocol.TStruct STRUCT_DESC = new org.apache.thrift.protocol.TStruct("ComputationalResourceScheduling");
 
   private static final org.apache.thrift.protocol.TField RESOURCE_HOST_ID_FIELD_DESC = new org.apache.thrift.protocol.TField("resourceHostId", org.apache.thrift.protocol.TType.STRING, (short)1);
-  private static final org.apache.thrift.protocol.TField TOTAL_CPUCOUNT_FIELD_DESC = new org.apache.thrift.protocol.TField("totalCPUCount", org.apache.thrift.protocol.TType.I32, (short)2);
+  private static final org.apache.thrift.protocol.TField TOTAL_CPU_COUNT_FIELD_DESC = new org.apache.thrift.protocol.TField("totalCpuCount", org.apache.thrift.protocol.TType.I32, (short)2);
   private static final org.apache.thrift.protocol.TField NODE_COUNT_FIELD_DESC = new org.apache.thrift.protocol.TField("nodeCount", org.apache.thrift.protocol.TType.I32, (short)3);
   private static final org.apache.thrift.protocol.TField NUMBER_OF_THREADS_FIELD_DESC = new org.apache.thrift.protocol.TField("numberOfThreads", org.apache.thrift.protocol.TType.I32, (short)4);
   private static final org.apache.thrift.protocol.TField QUEUE_NAME_FIELD_DESC = new org.apache.thrift.protocol.TField("queueName", org.apache.thrift.protocol.TType.STRING, (short)5);
@@ -74,7 +74,7 @@ import org.slf4j.LoggerFactory;
   }
 
   private String resourceHostId; // optional
-  private int totalCPUCount; // optional
+  private int totalCpuCount; // optional
   private int nodeCount; // optional
   private int numberOfThreads; // optional
   private String queueName; // optional
@@ -87,7 +87,7 @@ import org.slf4j.LoggerFactory;
   /** The set of fields this struct contains, along with convenience methods for finding and manipulating them. */
   @SuppressWarnings("all") public enum _Fields implements org.apache.thrift.TFieldIdEnum {
     RESOURCE_HOST_ID((short)1, "resourceHostId"),
-    TOTAL_CPUCOUNT((short)2, "totalCPUCount"),
+    TOTAL_CPU_COUNT((short)2, "totalCpuCount"),
     NODE_COUNT((short)3, "nodeCount"),
     NUMBER_OF_THREADS((short)4, "numberOfThreads"),
     QUEUE_NAME((short)5, "queueName"),
@@ -112,8 +112,8 @@ import org.slf4j.LoggerFactory;
       switch(fieldId) {
         case 1: // RESOURCE_HOST_ID
           return RESOURCE_HOST_ID;
-        case 2: // TOTAL_CPUCOUNT
-          return TOTAL_CPUCOUNT;
+        case 2: // TOTAL_CPU_COUNT
+          return TOTAL_CPU_COUNT;
         case 3: // NODE_COUNT
           return NODE_COUNT;
         case 4: // NUMBER_OF_THREADS
@@ -177,13 +177,13 @@ import org.slf4j.LoggerFactory;
   private static final int __JOBSTARTTIME_ISSET_ID = 4;
   private static final int __TOTALPHYSICALMEMORY_ISSET_ID = 5;
   private byte __isset_bitfield = 0;
-  private _Fields optionals[] = {_Fields.RESOURCE_HOST_ID,_Fields.TOTAL_CPUCOUNT,_Fields.NODE_COUNT,_Fields.NUMBER_OF_THREADS,_Fields.QUEUE_NAME,_Fields.WALL_TIME_LIMIT,_Fields.JOB_START_TIME,_Fields.TOTAL_PHYSICAL_MEMORY,_Fields.COMPUTATIONAL_PROJECT_ACCOUNT,_Fields.CHASSIS_NAME};
+  private _Fields optionals[] = {_Fields.RESOURCE_HOST_ID,_Fields.TOTAL_CPU_COUNT,_Fields.NODE_COUNT,_Fields.NUMBER_OF_THREADS,_Fields.QUEUE_NAME,_Fields.WALL_TIME_LIMIT,_Fields.JOB_START_TIME,_Fields.TOTAL_PHYSICAL_MEMORY,_Fields.COMPUTATIONAL_PROJECT_ACCOUNT,_Fields.CHASSIS_NAME};
   public static final Map<_Fields, org.apache.thrift.meta_data.FieldMetaData> metaDataMap;
   static {
     Map<_Fields, org.apache.thrift.meta_data.FieldMetaData> tmpMap = new EnumMap<_Fields, org.apache.thrift.meta_data.FieldMetaData>(_Fields.class);
     tmpMap.put(_Fields.RESOURCE_HOST_ID, new org.apache.thrift.meta_data.FieldMetaData("resourceHostId", org.apache.thrift.TFieldRequirementType.OPTIONAL, 
         new org.apache.thrift.meta_data.FieldValueMetaData(org.apache.thrift.protocol.TType.STRING)));
-    tmpMap.put(_Fields.TOTAL_CPUCOUNT, new org.apache.thrift.meta_data.FieldMetaData("totalCPUCount", org.apache.thrift.TFieldRequirementType.OPTIONAL, 
+    tmpMap.put(_Fields.TOTAL_CPU_COUNT, new org.apache.thrift.meta_data.FieldMetaData("totalCpuCount", org.apache.thrift.TFieldRequirementType.OPTIONAL, 
         new org.apache.thrift.meta_data.FieldValueMetaData(org.apache.thrift.protocol.TType.I32)));
     tmpMap.put(_Fields.NODE_COUNT, new org.apache.thrift.meta_data.FieldMetaData("nodeCount", org.apache.thrift.TFieldRequirementType.OPTIONAL, 
         new org.apache.thrift.meta_data.FieldValueMetaData(org.apache.thrift.protocol.TType.I32)));
@@ -216,7 +216,7 @@ import org.slf4j.LoggerFactory;
     if (other.isSetResourceHostId()) {
       this.resourceHostId = other.resourceHostId;
     }
-    this.totalCPUCount = other.totalCPUCount;
+    this.totalCpuCount = other.totalCpuCount;
     this.nodeCount = other.nodeCount;
     this.numberOfThreads = other.numberOfThreads;
     if (other.isSetQueueName()) {
@@ -240,8 +240,8 @@ import org.slf4j.LoggerFactory;
   @Override
   public void clear() {
     this.resourceHostId = null;
-    setTotalCPUCountIsSet(false);
-    this.totalCPUCount = 0;
+    setTotalCpuCountIsSet(false);
+    this.totalCpuCount = 0;
     setNodeCountIsSet(false);
     this.nodeCount = 0;
     setNumberOfThreadsIsSet(false);
@@ -280,25 +280,25 @@ import org.slf4j.LoggerFactory;
     }
   }
 
-  public int getTotalCPUCount() {
-    return this.totalCPUCount;
+  public int getTotalCpuCount() {
+    return this.totalCpuCount;
   }
 
-  public void setTotalCPUCount(int totalCPUCount) {
-    this.totalCPUCount = totalCPUCount;
-    setTotalCPUCountIsSet(true);
+  public void setTotalCpuCount(int totalCpuCount) {
+    this.totalCpuCount = totalCpuCount;
+    setTotalCpuCountIsSet(true);
   }
 
-  public void unsetTotalCPUCount() {
+  public void unsetTotalCpuCount() {
     __isset_bitfield = EncodingUtils.clearBit(__isset_bitfield, __TOTALCPUCOUNT_ISSET_ID);
   }
 
-  /** Returns true if field totalCPUCount is set (has been assigned a value) and false otherwise */
-  public boolean isSetTotalCPUCount() {
+  /** Returns true if field totalCpuCount is set (has been assigned a value) and false otherwise */
+  public boolean isSetTotalCpuCount() {
     return EncodingUtils.testBit(__isset_bitfield, __TOTALCPUCOUNT_ISSET_ID);
   }
 
-  public void setTotalCPUCountIsSet(boolean value) {
+  public void setTotalCpuCountIsSet(boolean value) {
     __isset_bitfield = EncodingUtils.setBit(__isset_bitfield, __TOTALCPUCOUNT_ISSET_ID, value);
   }
 
@@ -491,11 +491,11 @@ import org.slf4j.LoggerFactory;
       }
       break;
 
-    case TOTAL_CPUCOUNT:
+    case TOTAL_CPU_COUNT:
       if (value == null) {
-        unsetTotalCPUCount();
+        unsetTotalCpuCount();
       } else {
-        setTotalCPUCount((Integer)value);
+        setTotalCpuCount((Integer)value);
       }
       break;
 
@@ -571,8 +571,8 @@ import org.slf4j.LoggerFactory;
     case RESOURCE_HOST_ID:
       return getResourceHostId();
 
-    case TOTAL_CPUCOUNT:
-      return Integer.valueOf(getTotalCPUCount());
+    case TOTAL_CPU_COUNT:
+      return Integer.valueOf(getTotalCpuCount());
 
     case NODE_COUNT:
       return Integer.valueOf(getNodeCount());
@@ -611,8 +611,8 @@ import org.slf4j.LoggerFactory;
     switch (field) {
     case RESOURCE_HOST_ID:
       return isSetResourceHostId();
-    case TOTAL_CPUCOUNT:
-      return isSetTotalCPUCount();
+    case TOTAL_CPU_COUNT:
+      return isSetTotalCpuCount();
     case NODE_COUNT:
       return isSetNodeCount();
     case NUMBER_OF_THREADS:
@@ -655,12 +655,12 @@ import org.slf4j.LoggerFactory;
         return false;
     }
 
-    boolean this_present_totalCPUCount = true && this.isSetTotalCPUCount();
-    boolean that_present_totalCPUCount = true && that.isSetTotalCPUCount();
-    if (this_present_totalCPUCount || that_present_totalCPUCount) {
-      if (!(this_present_totalCPUCount && that_present_totalCPUCount))
+    boolean this_present_totalCpuCount = true && this.isSetTotalCpuCount();
+    boolean that_present_totalCpuCount = true && that.isSetTotalCpuCount();
+    if (this_present_totalCpuCount || that_present_totalCpuCount) {
+      if (!(this_present_totalCpuCount && that_present_totalCpuCount))
         return false;
-      if (this.totalCPUCount != that.totalCPUCount)
+      if (this.totalCpuCount != that.totalCpuCount)
         return false;
     }
 
@@ -762,12 +762,12 @@ import org.slf4j.LoggerFactory;
         return lastComparison;
       }
     }
-    lastComparison = Boolean.valueOf(isSetTotalCPUCount()).compareTo(other.isSetTotalCPUCount());
+    lastComparison = Boolean.valueOf(isSetTotalCpuCount()).compareTo(other.isSetTotalCpuCount());
     if (lastComparison != 0) {
       return lastComparison;
     }
-    if (isSetTotalCPUCount()) {
-      lastComparison = org.apache.thrift.TBaseHelper.compareTo(this.totalCPUCount, other.totalCPUCount);
+    if (isSetTotalCpuCount()) {
+      lastComparison = org.apache.thrift.TBaseHelper.compareTo(this.totalCpuCount, other.totalCpuCount);
       if (lastComparison != 0) {
         return lastComparison;
       }
@@ -881,10 +881,10 @@ import org.slf4j.LoggerFactory;
       }
       first = false;
     }
-    if (isSetTotalCPUCount()) {
+    if (isSetTotalCpuCount()) {
       if (!first) sb.append(", ");
-      sb.append("totalCPUCount:");
-      sb.append(this.totalCPUCount);
+      sb.append("totalCpuCount:");
+      sb.append(this.totalCpuCount);
       first = false;
     }
     if (isSetNodeCount()) {
@@ -1000,10 +1000,10 @@ import org.slf4j.LoggerFactory;
               org.apache.thrift.protocol.TProtocolUtil.skip(iprot, schemeField.type);
             }
             break;
-          case 2: // TOTAL_CPUCOUNT
+          case 2: // TOTAL_CPU_COUNT
             if (schemeField.type == org.apache.thrift.protocol.TType.I32) {
-              struct.totalCPUCount = iprot.readI32();
-              struct.setTotalCPUCountIsSet(true);
+              struct.totalCpuCount = iprot.readI32();
+              struct.setTotalCpuCountIsSet(true);
             } else { 
               org.apache.thrift.protocol.TProtocolUtil.skip(iprot, schemeField.type);
             }
@@ -1092,9 +1092,9 @@ import org.slf4j.LoggerFactory;
           oprot.writeFieldEnd();
         }
       }
-      if (struct.isSetTotalCPUCount()) {
-        oprot.writeFieldBegin(TOTAL_CPUCOUNT_FIELD_DESC);
-        oprot.writeI32(struct.totalCPUCount);
+      if (struct.isSetTotalCpuCount()) {
+        oprot.writeFieldBegin(TOTAL_CPU_COUNT_FIELD_DESC);
+        oprot.writeI32(struct.totalCpuCount);
         oprot.writeFieldEnd();
       }
       if (struct.isSetNodeCount()) {
@@ -1164,7 +1164,7 @@ import org.slf4j.LoggerFactory;
       if (struct.isSetResourceHostId()) {
         optionals.set(0);
       }
-      if (struct.isSetTotalCPUCount()) {
+      if (struct.isSetTotalCpuCount()) {
         optionals.set(1);
       }
       if (struct.isSetNodeCount()) {
@@ -1195,8 +1195,8 @@ import org.slf4j.LoggerFactory;
       if (struct.isSetResourceHostId()) {
         oprot.writeString(struct.resourceHostId);
       }
-      if (struct.isSetTotalCPUCount()) {
-        oprot.writeI32(struct.totalCPUCount);
+      if (struct.isSetTotalCpuCount()) {
+        oprot.writeI32(struct.totalCpuCount);
       }
       if (struct.isSetNodeCount()) {
         oprot.writeI32(struct.nodeCount);
@@ -1233,8 +1233,8 @@ import org.slf4j.LoggerFactory;
         struct.setResourceHostIdIsSet(true);
       }
       if (incoming.get(1)) {
-        struct.totalCPUCount = iprot.readI32();
-        struct.setTotalCPUCountIsSet(true);
+        struct.totalCpuCount = iprot.readI32();
+        struct.setTotalCpuCountIsSet(true);
       }
       if (incoming.get(2)) {
         struct.nodeCount = iprot.readI32();

http://git-wip-us.apache.org/repos/asf/airavata/blob/b376aa85/airavata-api/airavata-data-models/src/main/java/org/apache/airavata/model/workspace/experiment/DataTransferDetails.java
----------------------------------------------------------------------